@@ -4,7 +4,7 @@ import os
 from tqdm import tqdm
 from getpass import getpass
 
-def conn(db_name, user = None, password = None, db_address = 'ier-db-d1', user_profile_path = None):
+def conn(db_name, user = None, password = None, db_address = 'ier-db-d1', user_profile_path = None, test_connection=True):
         '''
         db_name
         user
@@ -36,5 +36,13 @@ def conn(db_name, user = None, password = None, db_address = 'ier-db-d1', user_p
         db_name = db_name
         conn_str = 'mssql+pyodbc://{}:{}@{}/{}?driver=SQL+Server'.format(user, password, db_address, db_name)
         conn = sqlalchemy.create_engine(conn_str,echo=False)    
+        
+        if test_connection:
+            try:
+                pd.read_sql('SELECT 1', conn)                    
+            except Exception as e:
+                print('Connection has failed.')
+                raise
+            print('Connection is ready.')
         return conn
 
